@@ -9,7 +9,11 @@ from ..baseclient import BaseClient
 from ..bencode import bencode
 from ..exceptions import FailedToExecuteException
 from ..torrent import TorrentData, TorrentFile, TorrentState
-from ..utils import calculate_minimum_expected_data, has_minimum_expected_data
+from ..utils import (
+    calculate_minimum_expected_data,
+    get_tracker_domain,
+    has_minimum_expected_data,
+)
 
 
 class QBittorrentClient(BaseClient):
@@ -70,7 +74,7 @@ class QBittorrentClient(BaseClient):
 
             tracker = ""
             if torrent["tracker"]:
-                tracker = ".".join(torrent["tracker"].split("/")[2].rsplit(".", 2)[1:])
+                tracker = get_tracker_domain(torrent["tracker"])
 
             result.append(
                 TorrentData(
@@ -135,6 +139,7 @@ class QBittorrentClient(BaseClient):
         data = {
             "savepath": str(destination_path),
             "skip_checking": (fast_resume and "true" or "false"),
+            "autoTMM": "false",
         }
         if stopped:
             data["paused"] = "true"
@@ -194,23 +199,34 @@ class QBittorrentClient(BaseClient):
             return Path(torrent["save_path"])
 
         prefixes = set(f["name"].split("/")[0] for f in torrent_files)
-        if len(prefixes) and list(prefixes)[0] == torrent["name"]:
+        if len(prefixes) == 1 and list(prefixes)[0] == torrent["name"]:
             return Path(torrent["save_path"]) / torrent["name"]
         else:
             return Path(torrent["save_path"])
 
     def get_files(self, infohash):
-        create_subfolder_enabled = self._check_create_subfolder_enabled()
-        files = self.call(
+        torrents = self.call(
+            "get", "/api/v2/torrents/info", params={"hashes": infohash}
+        ).json()
+        torrent_files = self.call(
             "get", "/api/v2/torrents/files", params={"hash": infohash}
         ).json()
+        torrent = torrents[0]
+        prefixes = set(f["name"].split("/")[0] for f in torrent_files)
+        trim_prefix = len(prefixes) == 1 and list(prefixes)[0] == torrent["name"]
         result = []
-        for f in files:
-            if create_subfolder_enabled and "/" in f["name"]:
+        for f in torrent_files:
+            if trim_prefix and "/" in f["name"]:
                 name = f["name"].split("/", 1)[1]
             else:
                 name = f["name"]
-            result.append(TorrentFile(name, f["size"], f["progress"] * 100,))
+            result.append(
+                TorrentFile(
+                    name,
+                    f["size"],
+                    f["progress"] * 100,
+                )
+            )
         return result
 
     def serialize_configuration(self):
