@@ -13,7 +13,11 @@ from ..baseclient import BaseClient
 from ..bencode import bencode
 from ..exceptions import FailedToExecuteException
 from ..torrent import TorrentData, TorrentFile, TorrentState
-from ..utils import calculate_minimum_expected_data, has_minimum_expected_data
+from ..utils import (
+    calculate_minimum_expected_data,
+    get_tracker_domain,
+    has_minimum_expected_data,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -24,16 +28,22 @@ class TransmissionClient(BaseClient):
 
     _session_id = ""
 
-    def __init__(self, url, session_path=None):
+    def __init__(self, url, session_path=None, username=None, password=None):
         self.url = url
         self.session_path = session_path and Path(session_path)
+        self.username = username
+        self.password = password
 
     def _call(self, method, **kwargs):
         logger.debug(f"Calling {method!r} args {kwargs!r}")
+        auth = None
+        if self.username and self.password:
+            auth = (self.username, self.password)
         return requests.post(
             self.url,
             data=json.dumps({"method": method, "arguments": kwargs}),
             headers={"X-Transmission-Session-Id": self._session_id},
+            auth=auth,
         )
 
     def call(self, method, **kwargs):
@@ -83,9 +93,7 @@ class TransmissionClient(BaseClient):
                 state = TorrentState.STOPPED
 
             if torrent["trackers"]:
-                tracker = ".".join(
-                    torrent["trackers"][0]["announce"].split("/")[2].rsplit(".", 2)[1:]
-                )
+                tracker = get_tracker_domain(torrent["trackers"][0]["announce"])
             else:
                 tracker = "None"
 
@@ -220,11 +228,11 @@ class TransmissionClient(BaseClient):
             name = f["name"]
             if not is_singlefile:
                 name = name.split("/", 1)[1]
-            result.append(
-                TorrentFile(
-                    name, f["length"], (f["length"] / f["bytesCompleted"]) * 100
-                )
-            )
+            if f["length"] > 0:
+                progress = (f["bytesCompleted"] / f["length"]) * 100
+            else:
+                progress = 100.0
+            result.append(TorrentFile(name, f["length"], progress))
 
         return result
 
@@ -261,4 +269,6 @@ class TransmissionClient(BaseClient):
         if not port:
             raise FailedToExecuteException("Unable to find port")
 
-        return cls(f"http://{ip}:{port}/transmission/rpc", config_path.parent)
+        return cls(
+            f"http://{ip}:{port}/transmission/rpc", session_path=config_path.parent
+        )
